# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
Jul 19 2013 | D060621 [PDF] [DOC] | Happy Nails & Spa v. Su 7/19/13 CA4/1 Case Details
Jul 18 2013 | D060064 [PDF] [DOC] | Acuna v. San Diego Gas & Electric 6/19/13 CA4/1 Case Details
Jul 10 2013 | D060260M [PDF] [DOC] | Dana Point v. Cal. Coastal Com. 7/10/13 CA4/1 Case Details
Jun 28 2013 | D062817 [PDF] [DOC] | In re Oscar A. 6/28/13 CA4/1 Case Details
Jun 21 2013 | D061261A [PDF] [DOC] | SB Liberty v. Isla Verde Asso. 5/22/13 CA4/1 Case Details
Jun 17 2013 | D060260 [PDF] [DOC] | Dana Point v. Cal. Coastal Com. 6/17/13 CA4/1 Case Details
Jun 14 2013 | D063023 [PDF] [DOC] | In re T.V. 5/29/13 CA4/1 Case Details
Jun 11 2013 | D061715 [PDF] [DOC] | City of San Diego v. Boggess 5/15/13 CA4/1 Case Details
Jun 11 2013 | D061056 [PDF] [DOC] | Do v. The Regents of the University of California 5/13/13 CA4/1 Case Details
Jun 11 2013 | D062550 [PDF] [DOC] | State Farm v. Huff 6/11/13 CA4/1 Case Details
Jun 03 2013 | D062005 [PDF] [DOC] | P. v. Woodall 5/13/13 CA4/1 Case Details
May 29 2013 | D062693 [PDF] [DOC] | P. v. Loper 5/29/13 CA4/1 Case Details
May 23 2013 | D062195 [PDF] [DOC] | Ronay Family L.P. v. Tweed 5/23/13 CA4/1 Case Details
May 22 2013 | D061891 [PDF] [DOC] | In re Timothy N. 5/22/13 CA4/1 Case Details
May 20 2013 | D061077 [PDF] [DOC] | In re Tobacco Cases I 4/26/13 CA4/1 Case Details
May 16 2013 | D060829 [PDF] [DOC] | Landstar Global v. Robinson & Robinson 5/16/13 CA4/1 Case Details
May 13 2013 | D062125 [PDF] [DOC] | P. v. Zavala 5/13/13 CA4/1 Case Details
May 06 2013 | D063022 [PDF] [DOC] | Sisson v. Super. Ct. 5/6/13 CA4/1 Case Details
Apr 29 2013 | D063076M [PDF] [DOC] | Battaglia Enterprises v. Super. Ct. 4/29/13 CA4/1 Case Details
Apr 29 2013 | D060029 [PDF] [DOC] | Jameson v. Desta 4/29/13 CA4/1 Case Details
Apr 26 2013 | D061653 [PDF] [DOC] | CA Dept. of Corr. v. St. Personnel Bd. 4/26/13 CA4/1 Case Details
Apr 25 2013 | D060999 [PDF] [DOC] | Taxpayers etc. v. San Diego USD 3/26/13 CA4/1 Case Details
Apr 22 2013 | D060057 [PDF] [DOC] | Ramirez v. Balboa Thrift etc. 3/21/13 CA4/1 Case Details
Apr 19 2013 | D062081 [PDF] [DOC] | In re Curtis S. 4/19/13 CA4/1 Case Details
Apr 19 2013 | D059976 [PDF] [DOC] | Chanda v. Federal Home Loans Corp. 4/19/13 CA4/1 Case Details
Apr 18 2013 | D060557 [PDF] [DOC] | Marr. of Simmons 4/18/13 CA4/1 Case Details
Apr 17 2013 | D060906 [PDF] [DOC] | Kleveland v. Siegel & Wolensky 4/17/13 CA4/1 Case Details
Apr 15 2013 | D061121 [PDF] [DOC] | Coastside Fishing Club v. Cal. Fish and Game Com. 4/15/13 CA4/1 Case Details
Apr 15 2013 | D060317A [PDF] [DOC] | P. v. Smith 4/15/13 CA4/1 Case Details
Apr 11 2013 | D063076 [PDF] [DOC] | Battaglia Enterprises v. Super. Ct. 4/11/13 CA4/1 Case Details
Apr 09 2013 | D059607 [PDF] [DOC] | P. v. Evans 4/9/13 CA4/1 Case Details
Apr 03 2013 | D060381 [PDF] [DOC] | Bedoe v. San Diego Cty. 4/3/13 CA4/1 Case Details
Mar 29 2013 | D062007 [PDF] [DOC] | P. v. Mora 3/29/13 CA4/1 Case Details
Mar 28 2013 | D060776 [PDF] [DOC] | Quigley v. McClellan 3/12/13 CA4/1 Case Details
Mar 27 2013 | D061055M [PDF] [DOC] | Dailey v. Sears, Roebuck 3/27/13 CA4/1 Case Details
Mar 27 2013 | D061960 [PDF] [DOC] | In re T.W. 3/5/13 CA4/1 Case Details
Mar 26 2013 | D059035 [PDF] [DOC] | San Diego USD v. Com. on Prof. Competence 3/26/13 CA4/1 Case Details
Mar 25 2013 | D062995 [PDF] [DOC] | Centex Homes v. Super. Ct. 3/25/13 CA4/1 Case Details